==> tccli-3.0.1021.1.tar.gz: tccli-3.0.1021.1/tccli/examples/wedata/v20210820/DescribeOpsMakePlanTasks.md <==
**Example 1: 成功获取补录计划任务**

成功获取补录计划任务

Input: 

```
tccli wedata DescribeOpsMakePlanTasks --cli-unfold-argument  \
    --PageNumber 1 \
    --PageSize 1 \
    --ProjectId 147056160274522xxxx \
    --PlanId e0bed861-0e95-44ca-9d10-28f29752xxxx
```

Output: 
```
{
    "Response": {
        "Data": {
            "Items": [
                {
                    "CompletePercent": 100,
                    "InstanceCount": 12,
                    "SuccessPercent": 100,
                    "TaskBaseInfo": {
                        "BrokerIp": null,
                        "ClusterId": null,
                        "CreateTime": null,
                        "Creator": null,
                        "Crontab": null,
                        "CrontabExpression": null,
                        "CycleNum": null,
                        "CycleStep": null,
                        "CycleType": null,
                        "CycleUnit": null,
                        "DelayTime": null,
                        "DependencyRel": null,
                        "DependencyWorkflow": null,
                        "EndDate": null,
                        "EndTime": null,
                        "EventListenerConfig": null,
                        "EventPublisherConfig": null,
                        "ExecutionEndTime": null,
                        "ExecutionStartTime": null,
                        "ExecutionTTL": null,
                        "FirstRunTime": null,
                        "FirstSubmitTime": null,
                        "FolderId": null,
                        "FolderName": null,
                        "InCharge": "incharge_xxx",
                        "InChargeId": null,
                        "InitStrategy": null,
                        "InstanceInitStrategy": null,
                        "LastSchedulerCommitTime": null,
                        "LastUpdate": null,
                        "Layer": null,
                        "LeftCoordinate": null,
                        "MaxDateTime": null,
                        "MinDateTime": null,
                        "NormalizedJobStartTime": null,
                        "Notes": null,
                        "OwnId": null,
                        "ProductName": null,
                        "ProjectId": null,
                        "ProjectIdent": null,
                        "ProjectName": null,
                        "RealWorkflowId": null,
                        "ResourceGroup": null,
                        "RetryAble": null,
                        "RetryWait": null,
                        "RunPriority": null,
                        "ScheduleDesc": null,
                        "SchedulerDesc": null,
                        "SelfDepend": null,
                        "ShowWorkflow": false,
                        "SourceServiceId": null,
                        "SourceServiceType": null,
                        "StartDate": null,
                        "StartTime": null,
                        "StartupTime": null,
                        "Status": null,
                        "TargetServiceId": null,
                        "TargetServiceType": null,
                        "TaskAction": null,
                        "TaskId": "2023052809431xxxx",
                        "TaskLinkInfo": null,
                        "TaskName": "部分成功任务子任务",
                        "TaskType": null,
                        "TaskTypeDesc": "Shell",
                        "TaskTypeId": null,
                        "TenantId": null,
                        "TopCoordinate": null,
                        "TryLimit": null,
                        "UpdateTime": null,
                        "UpdateUser": null,
                        "UpdateUserId": null,
                        "UserId": null,
                        "VirtualFlag": false,
                        "VirtualTaskId": null,
                        "VirtualTaskStatus": null,
                        "WorkflowId": null,
                        "WorkflowName": null,
                        "YarnQueue": null
                    }
                }
            ],
            "PageNumber": 1,
            "PageSize": 1,
            "TotalCount": 1,
            "TotalPage": 1
        },
        "RequestId": "36f271a5-97ab-47fc-865b-5c3eaf2axxxx"
    }
}
```

==> tccli-3.0.1102.1.tar.gz: tccli-3.0.1102.1/tccli/examples/wedata/v20210820/DescribeOpsMakePlanTasks.md <==
**Example 1: 获取补录计划任务**

数据补录-获取补录计划任务

Input: 

```
tccli wedata DescribeOpsMakePlanTasks --cli-unfold-argument  \
    --PageNumber 1 \
    --PageSize 1 \
    --ProjectId 14705274522 \
    --PlanId f47ac10b-58cc-4372-a567-0e02b2c3d479
```

Output: 
```
{
    "Response": {
        "Data": {
            "TotalCount": 0,
            "TotalPage": 0,
            "PageCount": 0,
            "PageNumber": 0,
            "PageSize": 0,
            "Items": [
                {
                    "TaskBaseInfo": {
                        "TaskId": "19920226154637701",
                        "VirtualTaskId": null,
                        "VirtualFlag": false,
                        "TaskName": "测试任务",
                        "WorkflowId": null,
                        "RealWorkflowId": null,
                        "WorkflowName": null,
                        "FolderId": null,
                        "FolderName": null,
                        "CreateTime": null,
                        "LastUpdate": null,
                        "Status": null,
                        "InCharge": "tom;jerry",
                        "InChargeId": null,
                        "StartTime": null,
                        "EndTime": null,
                        "ExecutionStartTime": null,
                        "ExecutionEndTime": null,
                        "CycleType": null,
                        "CycleStep": 1,
                        "CrontabExpression": null,
                        "DelayTime": 1,
                        "StartupTime": 1,
                        "RetryWait": 1,
                        "RetryAble": 1,
                        "TaskAction": null,
                        "TryLimit": 1,
                        "RunPriority": 1,
                        "TaskType": null,
                        "BrokerIp": null,
                        "ClusterId": null,
                        "MinDateTime": null,
                        "MaxDateTime": null,
                        "ExecutionTTL": 0,
                        "SelfDepend": null,
                        "LeftCoordinate": 0,
                        "TopCoordinate": 0,
                        "Notes": null,
                        "InstanceInitStrategy": null,
                        "YarnQueue": null,
                        "LastSchedulerCommitTime": null,
                        "NormalizedJobStartTime": null,
                        "SchedulerDesc": null,
                        "ResourceGroup": null,
                        "Creator": null,
                        "DependencyRel": null,
                        "DependencyWorkflow": null,
                        "EventListenerConfig": null,
                        "EventPublisherConfig": null,
                        "VirtualTaskStatus": null,
                        "TaskLinkInfo": {
                            "Id": null,
                            "LinkKey": null,
                            "TaskFrom": null,
                            "TaskTo": null,
                            "InCharge": null,
                            "LinkDependencyType": null,
                            "Offset": null,
                            "LinkType": null,
                            "WorkflowId": null
                        },
                        "ProductName": null,
                        "ProjectId": null,
                        "ProjectIdent": null,
                        "ProjectName": null,
                        "OwnId": null,
                        "UserId": null,
                        "TenantId": null,
                        "UpdateUser": null,
                        "UpdateTime": null,
                        "UpdateUserId": null,
                        "TaskTypeId": null,
                        "TaskTypeDesc": "Shell",
                        "ShowWorkflow": false,
                        "FirstSubmitTime": null,
                        "FirstRunTime": null,
                        "ScheduleDesc": null,
                        "CycleNum": 0,
                        "Crontab": null,
                        "StartDate": null,
                        "EndDate": null,
                        "CycleUnit": null,
                        "InitStrategy": null,
                        "Layer": null,
                        "SourceServiceId": null,
                        "SourceServiceType": null,
                        "TargetServiceId": null,
                        "TargetServiceType": null,
                        "TasksStr": null,
                        "Submit": true,
                        "ExecutorGroupId": null,
                        "ExecutorGroupName": null
                    },
                    "InstanceCount": 0,
                    "CompletePercent": 0,
                    "SuccessPercent": 0,
                    "InstanceTotalCount": 0
                }
            ]
        },
        "RequestId": "f47ac10b-58cc-4372-a567-0e02b2c3d479"
    }
}
```
